@@ -96,6 +96,10 @@ class App(BoxContainer):
             reactDatas=reactData,
             watchInfo=watchInfo)
 
+    def __reset_data(self):
+        self._children.clear()
+        self.df_manager.reset()
+
     def to_html(self, file):
         file = Path(file)
         symbol = '"__{{__config_data__}}___"'
@@ -120,3 +124,4 @@ class App(BoxContainer):
             Path(file).write_text(res, 'utf8')
 
         print(f'to html:{file.absolute()}')
+        self.__reset_data()
