@@ -10,6 +10,7 @@ from pyvisflow.core.components.input import Input
 from pyvisflow.core.components.inputNumber import InputNumber
 from pyvisflow.core.components.plotly import Plotly
 from pyvisflow.core.components.select import Select
+from pyvisflow.core.components.text import Text
 from pyvisflow.core.layout import MarkdownLayout
 from pyvisflow.core.props import BoolTypePropInfo, NamePropInfo
 
@@ -38,11 +39,18 @@ class BoxContainer(Container):
 
     def box(self, ):
         cp = BoxContainer()
+        cp._on_before_data_fn = self._on_before_data_fn
         self.add_child(cp)
         return cp
 
-    def dataTable(self, dataframe: pd.DataFrame, page_size=10):
-        cp = DataTable(self._on_before_data_fn(dataframe), page_size)
+    def text(self,value:str):
+        cp = Text(value)
+        self.add_child(cp)
+        return cp
+
+    def dataTable(self, dataframe: pd.DataFrame, page_size=5):
+        cp = DataTable(self._on_before_data_fn(dataframe))
+        cp.page_size = page_size
         self.add_child(cp)
         return cp
 
