@@ -35,6 +35,9 @@ class DataFrameManager():
 
         return TDataFrameInfo(id=data_id)
 
+    def reset(self):
+        self.data_dict.clear()
+
     def to_model(self) -> List[TDataframe]:
 
         return [
