@@ -23,7 +23,7 @@ class FnsMethodPropInfo(AbsPropInfo):
 
     @staticmethod
     def __to_code(v: Union[str, int, TypePropInfo]):
-        if isinstance(v, (str, int)):
+        if (v is None) or isinstance(v, (str, int)):
             return value2code(v)
         return v.valuator.cal(v)
 
